Learn R Programming

phase1RMD (version 1.0.9)

tox.matrix: Probability matrix for toxicity

Description

This data set is a four-dimension array (Dose, Cycle, Toxicity Type, Toxicity Grade) specifying the probabilities of the occurrences of certain grades for certain types of toxicities.

Usage

tox.matrix

Arguments

Format

A 4-dimension array.

References

Yin, Jun, et al. "A Bayesian dose finding design incorporating toxicity data from multiple treatment cycles." Statistics in Medicine 36.1 (2017): 67-80.